==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/EncoderProcessorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Encoder processor allows for encoding of the input content. For example, it can used to change the resolution from 4K to 1280x720.
 * @property inputs An array of upstream node references within the topology to be used as inputs for this node.
 * @property name Node name. Must be unique within the topology.
 * @property preset The encoder preset, which defines the recipe or instructions on how the input content should be processed.
 * @property type The discriminator for derived types.
 * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
 */
public data class EncoderProcessorArgs(
    public val inputs: Output<List<NodeInputArgs>>,
    public val name: Output<String>,
    public val preset: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs.builder()
            .inputs(inputs.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .preset(
                preset.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncoderProcessorArgs].
 */
@PulumiTagMarker
public class EncoderProcessorArgsBuilder internal constructor() {
    private var inputs: Output<List<NodeInputArgs>>? = null

    private var name: Output<String>? = null

    private var preset: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("domndbkwafwrunkd")
    public suspend fun inputs(`value`: Output<List<NodeInputArgs>>) {
        this.inputs = value
    }

    @JvmName("mlxmcirpeqnnpwma")
    public suspend fun inputs(vararg values: Output<NodeInputArgs>) {
        this.inputs = Output.all(values.asList())
    }

    /**
     * @param values An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("ihoqyrbmrvlbphlp")
    public suspend fun inputs(values: List<Output<NodeInputArgs>>) {
        this.inputs = Output.all(values)
    }

    /**
     * @param value Node name. Must be unique within the topology.
     */
    @JvmName("gayoikknlemuitgv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("gueoavouiwbaihmx")
    public suspend
    fun preset(`value`: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>) {
        this.preset = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
     */
    @JvmName("docoxhgrqlwgshgx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("vhavxxeclihrqrcs")
    public suspend fun inputs(`value`: List<NodeInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("snymoukdlrhhcdgx")
    public suspend fun inputs(argument: List<suspend NodeInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { NodeInputArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("yywxdgqtvlgrsgqy")
    public suspend fun inputs(vararg argument: suspend NodeInputArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { NodeInputArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("piyakehvjbnkljlc")
    public suspend fun inputs(argument: suspend NodeInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NodeInputArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param values An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("fhtmgntopmoflsxs")
    public suspend fun inputs(vararg values: NodeInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param value Node name. Must be unique within the topology.
     */
    @JvmName("wupgbgfpstrhqsbo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("lehkxtomqmaxfnui")
    public suspend fun preset(`value`: Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("ykiofrfcllrwpvwv")
    public fun preset(`value`: EncoderCustomPresetArgs) {
        val toBeMapped = Either.ofLeft<EncoderCustomPresetArgs, EncoderSystemPresetArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("ilupqmpayehskoku")
    public fun preset(`value`: EncoderSystemPresetArgs) {
        val toBeMapped = Either.ofRight<EncoderCustomPresetArgs, EncoderSystemPresetArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
     */
    @JvmName("gntotnuaqpbfqkpf")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): EncoderProcessorArgs = EncoderProcessorArgs(
        inputs = inputs ?: throw PulumiNullFieldException("inputs"),
        name = name ?: throw PulumiNullFieldException("name"),
        preset = preset ?: throw PulumiNullFieldException("preset"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/EncoderProcessorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Encoder processor allows for encoding of the input content. For example, it can used to change the resolution from 4K to 1280x720.
 * @property inputs An array of upstream node references within the topology to be used as inputs for this node.
 * @property name Node name. Must be unique within the topology.
 * @property preset The encoder preset, which defines the recipe or instructions on how the input content should be processed.
 * @property type The discriminator for derived types.
 * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
 */
public data class EncoderProcessorArgs(
    public val inputs: Output<List<NodeInputArgs>>,
    public val name: Output<String>,
    public val preset: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.EncoderProcessorArgs.builder()
            .inputs(inputs.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .preset(
                preset.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncoderProcessorArgs].
 */
@PulumiTagMarker
public class EncoderProcessorArgsBuilder internal constructor() {
    private var inputs: Output<List<NodeInputArgs>>? = null

    private var name: Output<String>? = null

    private var preset: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("swavxaeaeadklbbe")
    public suspend fun inputs(`value`: Output<List<NodeInputArgs>>) {
        this.inputs = value
    }

    @JvmName("xhvdclxisqywyvfr")
    public suspend fun inputs(vararg values: Output<NodeInputArgs>) {
        this.inputs = Output.all(values.asList())
    }

    /**
     * @param values An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("praueltspreruumb")
    public suspend fun inputs(values: List<Output<NodeInputArgs>>) {
        this.inputs = Output.all(values)
    }

    /**
     * @param value Node name. Must be unique within the topology.
     */
    @JvmName("ajiqobavglivbfuc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("hfrukbcydaoobjti")
    public suspend
    fun preset(`value`: Output<Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>>) {
        this.preset = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
     */
    @JvmName("jpoonmcqfwtrtlng")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("mccecfdlwiittcwg")
    public suspend fun inputs(`value`: List<NodeInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("mhnbpwpeoandcguq")
    public suspend fun inputs(argument: List<suspend NodeInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { NodeInputArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("omfkdabpyphljglo")
    public suspend fun inputs(vararg argument: suspend NodeInputArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { NodeInputArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param argument An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("njxfqmtsqxpflljm")
    public suspend fun inputs(argument: suspend NodeInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NodeInputArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.inputs = mapped
    }

    /**
     * @param values An array of upstream node references within the topology to be used as inputs for this node.
     */
    @JvmName("ertcgvurtmchwmex")
    public suspend fun inputs(vararg values: NodeInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param value Node name. Must be unique within the topology.
     */
    @JvmName("skgxunvufpgupppq")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("vwcywvxapnktusyv")
    public suspend fun preset(`value`: Either<EncoderCustomPresetArgs, EncoderSystemPresetArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("xycbfjwtkuybmkal")
    public fun preset(`value`: EncoderCustomPresetArgs) {
        val toBeMapped = Either.ofLeft<EncoderCustomPresetArgs, EncoderSystemPresetArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The encoder preset, which defines the recipe or instructions on how the input content should be processed.
     */
    @JvmName("fikoxnrmywagdgsl")
    public fun preset(`value`: EncoderSystemPresetArgs) {
        val toBeMapped = Either.ofRight<EncoderCustomPresetArgs, EncoderSystemPresetArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preset = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.EncoderProcessor'.
     */
    @JvmName("aotgdeofxxmacquv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): EncoderProcessorArgs = EncoderProcessorArgs(
        inputs = inputs ?: throw PulumiNullFieldException("inputs"),
        name = name ?: throw PulumiNullFieldException("name"),
        preset = preset ?: throw PulumiNullFieldException("preset"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
